@@ -14,7 +14,7 @@ import pprint
 import sentry_tracpost
 
 class TracPostOptionsForm(forms.Form):
-    xmlrpc_url = forms.URLField(required=True,
+    xmlrpc_url = forms.CharField(required=True,
                           label='Trac XMLRPC URL',
                           help_text='e.g. https://user:pass@hostname.com:91/trac/login/rpc')
 
